# program

# statement

# if_stmt

# IF

# comparison_op operations

# expr

# string_expr

# '^' operations

# nested_string_expression

# CONCAT

# string

# bool_expr

# 'or' operations

# 'and' operations

# 'not' operations

# NOT

# TRUE

# FALSE

# conditional_expr

# nested_bool_operand_expression

# AND

# OR

# arith_expr

# add_op operations

# mul_op operations

# unary_minus operations

# unary_minus

# float

# integer

# nested_arith_operand_expression

# mul_op

# MUL

# DIV

# MOD

# add_op

# ADD

# SUB

# nested_expr_expression

# comparison_op

# LE

# GE

# LT

# GT

# EQ

# NE

# block

# ELIF

# ELSE

# function_def

# DEF

# identifier

# LPAR

# RPAR

# COLON

# END

# assignment_stmt

# dict_set_stmt

# LSQUARE

# RSQUARE

# DICT_SET

# TERM

# end of line

# end of text